<#macro mainLayout active bodyClass>
<!doctype html>
<html>
<head>
    <meta charset="utf-8">
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
    <meta name="robots" content="noindex, nofollow">

    <title>${msg("accountManagementTitle")}</title>

    <link rel="icon" href="${url.resourcesPath}/img/pub.solar.svg" />

    <link href="${url.resourcesPath}/css/index.css?v4" rel="stylesheet" />

    <script defer src="${url.resourcesPath}/js/background.js" type="text/javascript"></script>
    <script defer src="${url.resourcesPath}/js/i18n.js" type="text/javascript"></script>

    <#if properties.stylesCommon?has_content>
        <#list properties.stylesCommon?split(' ') as style>
            <link href="${url.resourcesCommonPath}/${style}" rel="stylesheet" />
        </#list>
    </#if>
    <#if properties.styles?has_content>
        <#list properties.styles?split(' ') as style>
            <link href="${url.resourcesPath}/${style}" rel="stylesheet" />
        </#list>
    </#if>
    <#if properties.scripts?has_content>
        <#list properties.scripts?split(' ') as script>
            <script defer src="${url.resourcesPath}/${script}" type="text/javascript"></script>
        </#list>
    </#if>
    <#if properties.scriptsCommon?has_content>
        <#list properties.scriptsCommon?split(' ') as script>
            <script defer src="${url.resourcesCommonPath}/${script}" type="text/javascript"></script>
        </#list>
    </#if>
</head>
<body class="ps-main ps-main_full">
  <div
    id="background"
    class="ps-background ps-main--background"
  >
    <div
      id="x1312"
      class="ps-background--1312"
    >0x1312</div>
    <div
      id="logo"
      class="ps-background--logo ps-logo"
    >
      <img
        class="ps-logo--base"
        src="${url.resourcesPath}/img/pub.solar.svg"
      />
      </div>
  </div>
  <main class="ps-main--page ps-page">
    <header class="ps-page--header ps-header">
        <a href="https://pub.solar/" class="ps-homelink">pub.solar/</a>

        <#if realm.internationalizationEnabled  && locale.supported?size gt 1>
          <select
            class="ps-i18n-links ps-header--i18n"
            id="language-toggle"
          >
            <#list locale.supported as l>
              <option
                value="${l.url}"
                <#if locale.current == l.label>selected</#if>
              >${l.label}</option>
            </#list>
          </select>
        </#if>

        <nav class="ps-header--nav" role="navigation">
            <ul class="ps-header--nav-list">
                <#if referrer?has_content && referrer.url?has_content>
                  <li class="ps-header--nav-item">
                    <a
                      href="${referrer.url}"
                      class="ps-link"
                      id="referrer"
                    >${msg("backTo",referrer.name)}</a>
                  </li>
                </#if>
                <li class="ps-header--nav-item">
                  <a
                    href="${url.getLogoutUrl()}"
                    class="ps-link"
                  >${msg("doSignOut")}</a>
                </li>
            </ul>
        </nav>
    </header>

    <section class="ps-page--section ps-page--section_full">
        <nav class="ps-section-nav">
            <ul class="ps-section-nav--list">
                <li class="ps-section-nav--link <#if active=='account'>ps-section-nav--link_active</#if>">
                  <a href="${url.accountUrl}">${msg("account")}</a>
                </li>
                <#if features.passwordUpdateSupported>
                  <li class="ps-section-nav--link <#if active=='password'>ps-section-nav--link_active</#if>">
                    <a href="${url.passwordUrl}">${msg("password")}</a>
                  </li>
                </#if>
                <li class="ps-section-nav--link <#if active=='totp'>ps-section-nav--link_active</#if>">
                  <a href="${url.totpUrl}">${msg("authenticator")}</a>
                </li>
                <#if features.identityFederation>
                  <li class="ps-section-nav--link <#if active=='social'>ps-section-nav--link_active</#if>">
                    <a href="${url.socialUrl}">${msg("federatedIdentity")}</a>
                  </li>
                </#if>
                <li class="ps-section-nav--link <#if active=='sessions'>ps-section-nav--link_active</#if>">
                  <a href="${url.sessionsUrl}">${msg("sessions")}</a>
                </li>
                <li class="ps-section-nav--link <#if active=='applications'>ps-section-nav--link_active</#if>">
                  <a href="${url.applicationsUrl}">${msg("applications")}</a>
                </li>
                <#if features.log>
                  <li class="ps-section-nav--link <#if active=='log'>ps-section-nav--link_active</#if>">
                    <a href="${url.logUrl}">${msg("log")}</a>
                  </li>
                </#if>
                <#if realm.userManagedAccessAllowed && features.authorization>
                  <li class="ps-section-nav--link <#if active=='authorization'>ps-section-nav--link_active</#if>">
                    <a href="${url.resourceUrl}">${msg("myResources")}</a>
                  </li>
                </#if>
            </ul>
        </nav>

        <div class="ps-page--section-contents">
            <#if message?has_content>
                <div class="alert alert-${message.type}">
                    <#if message.type=='success' ><span class="pficon pficon-ok"></span></#if>
                    <#if message.type=='error' ><span class="pficon pficon-error-circle-o"></span></#if>
                    <span class="kc-feedback-text">${kcSanitize(message.summary)?no_esc}</span>
                </div>
            </#if>

            <#nested "content">
        </div>
    </section>
  </main>

</body>
</html>
</#macro>
